import * as i0 from '@angular/core';
import { forwardRef, Injectable, Inject, NgModule, CUSTOM_ELEMENTS_SCHEMA } from '@angular/core';
import * as i1 from '@angular/common/http';
import { HttpHeaders, HttpClient, HttpParams, HttpClientModule } from '@angular/common/http';
import { map } from 'rxjs/operators';
import * as i2 from '@yukawa/chain-base-angular-client';
import { RestAspect, ConfigService } from '@yukawa/chain-base-angular-client';
import _ from 'lodash';
import { BaseRealm } from '@yukawa/chain-base-angular-domain';
import { MainRealm } from '@yukawa/chain-main-angular-core';
import { CommonModule } from '@angular/common';
import * as i1$1 from '@ngx-translate/core';
import { TranslateModule } from '@ngx-translate/core';

class AccountService extends RestAspect {
    constructor(http, configService) {
        super(http, configService);
    }
    queryAccount(filter) {
        return this.query(this.formatServiceUrl('/query'), filter);
    }
    queryAccountsAsList(partnerType, keyword) {
        return this.queryAccount({
            pager: { pageSize: 100, firstResult: 0 },
            keyword: keyword,
            partnerType: partnerType
        }).pipe(map(value => value.items));
    }
    mergeAccount(partner) {
        return this.edit(this.formatServiceUrl(`/merge`), partner, { method: 'post' });
    }
    collectionsPut(partner) {
        return this.http.post(this.formatServiceUrl('/collections/put'), partner);
    }
    collectionsRemove(partner) {
        return this.http.post(this.formatServiceUrl('/collections/remove'), partner);
    }
    collectionsAppend(partner) {
        return this.http.post(this.formatServiceUrl('/collections/append'), partner);
    }
    loadAccount(id) {
        return this.load(`${this.formatServiceUrl('')}/?key=${id}`)
            .pipe(map(value => this.checkNotNull(value)));
    }
    saveAccount(account, type = "create") {
        return this.edit(this.formatServiceUrl(`/${type}`), account, { method: 'post' });
    }
    deleteAccount(id) {
        return this.http.delete(`${this.formatServiceUrl('')}/?key=${id}`);
    }
    newAccount() {
        return this.http.post(`${this.formatServiceUrl('/new')}`, {})
            .pipe(map(value => this.checkNotNull(value)));
    }
    export(filter) {
        let opts = {
            headers: new HttpHeaders({
                'Content-Type': 'application/json'
                //'Accept': 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet'
            })
        };
        return this.download(`${this.formatServiceUrl('/export')}`, filter, opts);
    }
    importPartners(data) {
        return this.http.post(`${this.formatServiceUrl('/import')}`, data);
    }
    formatServiceUrl(path = '') {
        return this.configService.formatUrl("partnerUrl") + path;
    }
}
/** @nocollapse */ AccountService.ɵfac = function AccountService_Factory(t) { return new (t || AccountService)(i0.ɵɵinject(forwardRef(() => HttpClient)), i0.ɵɵinject(forwardRef(() => ConfigService))); };
/** @nocollapse */ AccountService.ɵprov = i0.ɵɵdefineInjectable({ token: AccountService, factory: AccountService.ɵfac, providedIn: 'root' });
/*@__PURE__*/ (function () { i0.ɵsetClassMetadata(AccountService, [{
        type: Injectable,
        args: [{
                providedIn: 'root'
            }]
    }], function () { return [{ type: i1.HttpClient, decorators: [{
                type: Inject,
                args: [forwardRef(() => HttpClient)]
            }] }, { type: i2.ConfigService, decorators: [{
                type: Inject,
                args: [forwardRef(() => ConfigService)]
            }] }]; }, null); })();
class RelationService extends RestAspect {
    constructor(http, configService) {
        super(http, configService);
    }
    searchRelation(filter) {
        return this.search(this.formatServiceUrl('/search'), filter);
    }
    queryRelation(filter) {
        return this.query(this.formatServiceUrl('/query'), filter);
    }
    loadRelation(id) {
        return this.load(`${this.formatServiceUrl('')}/?key=${id}`)
            .pipe(map(value => this.checkNotNull(value)));
    }
    saveRelation(relation, type = "create") {
        return this.edit(this.formatServiceUrl(`/${type}`), relation, { method: 'post' });
    }
    deleteRelation(id) {
        return this.http.delete(`${this.formatServiceUrl('')}/?key=${id}`);
    }
    traverseRelations(partnerId, role, traversalDir) {
        return this.http.get(`${this.formatServiceUrl('/traverse')}?partnerId=${partnerId}&role=${role}&traversalDir=${traversalDir}`);
    }
    formatServiceUrl(path = '') {
        return this.configService.formatUrl("relationUrl") + path;
    }
}
/** @nocollapse */ RelationService.ɵfac = function RelationService_Factory(t) { return new (t || RelationService)(i0.ɵɵinject(forwardRef(() => HttpClient)), i0.ɵɵinject(forwardRef(() => ConfigService))); };
/** @nocollapse */ RelationService.ɵprov = i0.ɵɵdefineInjectable({ token: RelationService, factory: RelationService.ɵfac, providedIn: 'root' });
/*@__PURE__*/ (function () { i0.ɵsetClassMetadata(RelationService, [{
        type: Injectable,
        args: [{
                providedIn: 'root'
            }]
    }], function () { return [{ type: i1.HttpClient, decorators: [{
                type: Inject,
                args: [forwardRef(() => HttpClient)]
            }] }, { type: i2.ConfigService, decorators: [{
                type: Inject,
                args: [forwardRef(() => ConfigService)]
            }] }]; }, null); })();
class ContactLogService extends RestAspect {
    constructor(http, configService) {
        super(http, configService, configService.formatUrl("contactLogUrl"));
    }
    searchContactLog(filter) {
        return this.search(this.formatServiceUrl('/search'), filter);
    }
    queryContactLog(filter) {
        return this.query(this.formatServiceUrl('/query'), filter);
    }
    loadContactLog(id) {
        return this.load(`${this.formatServiceUrl('')}/?key=${id}`)
            .pipe(map(value => this.checkNotNull(value)));
    }
    saveContactLog(contactLog, type = "create") {
        return this.edit(this.formatServiceUrl(`/${type}`), contactLog, { method: 'post' });
    }
    deleteContactLog(id) {
        return this.http.delete(`${this.formatServiceUrl('')}/?key=${id}`);
    }
}
/** @nocollapse */ ContactLogService.ɵfac = function ContactLogService_Factory(t) { return new (t || ContactLogService)(i0.ɵɵinject(forwardRef(() => HttpClient)), i0.ɵɵinject(forwardRef(() => ConfigService))); };
/** @nocollapse */ ContactLogService.ɵprov = i0.ɵɵdefineInjectable({ token: ContactLogService, factory: ContactLogService.ɵfac, providedIn: 'root' });
/*@__PURE__*/ (function () { i0.ɵsetClassMetadata(ContactLogService, [{
        type: Injectable,
        args: [{
                providedIn: 'root'
            }]
    }], function () { return [{ type: i1.HttpClient, decorators: [{
                type: Inject,
                args: [forwardRef(() => HttpClient)]
            }] }, { type: i2.ConfigService, decorators: [{
                type: Inject,
                args: [forwardRef(() => ConfigService)]
            }] }]; }, null); })();

var PartnerType$1;
(function (PartnerType) {
    PartnerType["COMPANY"] = "company";
    PartnerType["PERSON"] = "person";
})(PartnerType$1 || (PartnerType$1 = {}));
var ContactLogStatus;
(function (ContactLogStatus) {
    ContactLogStatus["NEW"] = "New";
    ContactLogStatus["DONE"] = "Done";
    ContactLogStatus["ARCHIVED"] = "Archived";
    ContactLogStatus["PENDING"] = "Pending";
})(ContactLogStatus || (ContactLogStatus = {}));
const partnerTypes$1 = [];
const contactLogStatus = [];
for (let status in ContactLogStatus) {
    contactLogStatus.push(ContactLogStatus[status]);
}
for (let n in PartnerType$1) {
    partnerTypes$1.push(PartnerType$1[n]);
}

/*
export interface RelationFilter extends TableFilter {
    keyword?: string
    partnerId?: string
    partnerTargetId?: string
    partnerSourceId?: string
    targetOrSourceIds?: string[]
    role?: string;
    //"partnerTargetId\", \"orderBy\", \"role\", \"relationId\", \"keyword\", \"partnerSourceId\
}

export interface ContactLogFilter extends TableFilter {
    keyword?: string
    partnerId?: string
    communicationChannel?: string
    participantId?: string
    //\"timeout\", \"status\", \"pager\", \"orderBy\", \"keyword\", \"communicationChannel\", \"orderDir\", \"contactLogId\"
}
*/

const withType = (partner, type) => partner.partnerType === type;
const withId = (partner, id) => partner.partnerId === id;
const sortByCompanyName = (p1, p2) => {
    if (p1.companyName && p2.companyName) {
        return p1.companyName.localeCompare(p2.companyName);
    }
    return 0;
};
const sortByLastName = (p1, p2) => {
    if (p1.lastName && p2.lastName) {
        return p1.lastName.localeCompare(p2.lastName);
    }
    return 0;
};
class AccountUtilities {
    static getPartnerById(partners, partnerId) {
        const ifExist = partners.find(val => val.partnerId === partnerId);
        return ifExist;
    }
    static getDisplayName(partner, partnerType) {
        if (partner && partner.partnerType) {
            return partner.partnerType === PartnerType$1.COMPANY ? partner.companyName : partner.firstName + ' ' + partner.lastName;
        }
        if (partnerType) {
            return partnerType === PartnerType$1.COMPANY.toString() ? partner.companyName : partner.firstName + ' ' + partner.lastName;
        }
        return "";
    }
    static compareWith(partner1, partner2) {
        return partner1 && partner2 ? partner1.partnerId === partner2.partnerId : -1;
    }
    static buildPartnerInfo(partner) {
        const subset = (({ companyName, email, firstName, lastName, partnerId, shortName }) => ({
            companyName,
            email,
            firstName,
            lastName,
            partnerId,
            shortName
        }));
        return subset(partner);
    }
    static filterAccounts(accounts, subject, filterCtrl) {
        if (!accounts) {
            return;
        }
        // get the search keyword
        let search = filterCtrl.value;
        if (!search) {
            subject.next(accounts.slice());
            return;
        }
        else {
            search = search.toLowerCase();
        }
        // filter the accounts
        subject.next(accounts.filter(account => {
            if (account.companyName) {
                return account.companyName.toLowerCase().indexOf(search) > -1;
            }
            if (account.firstName && account.lastName) {
                return account.firstName.toLowerCase().indexOf(search) > -1 || account.lastName.toLowerCase().indexOf(search) > -1;
            }
        }));
    }
}

class AddressUtils {
    constructor() {
    }
    static findAddressByType(address, type) {
        const _address = address.filter(val => val.type != null).find(val => val.type === this.TYPE_INVOICE);
        return _address;
    }
    static getFormGroup(fb, initial, validators) {
        const group = fb.group({
            type: [null, null],
            street: [null, null],
            houseNumber: [null, null],
            countryCode: [null, null],
            city: [null, null],
            zipCode: [null, null],
            desc: [null, null]
        });
        if (initial) {
            group.patchValue(initial);
        }
        return group;
    }
    static addAddressToFormArray(fa, fb, initial) {
        let formArray = fa;
        formArray.push(this.getFormGroup(fb, initial));
    }
    static addAndGetAddress(fa, fb, initial) {
        let formArray = fa;
        let group = this.getFormGroup(fb, initial);
        formArray.push(group);
        return group;
    }
}
AddressUtils.TYPE_INVOICE = "INVOICE";

var PartnerType;
(function (PartnerType) {
    PartnerType["COMPANY"] = "company";
    PartnerType["PERSON"] = "person";
})(PartnerType || (PartnerType = {}));
const partnerTypes = [];
for (let n in PartnerType) {
    partnerTypes.push(PartnerType[n]);
}
// export interface RelationConfig {
//     source: PartnerType;
//     target: PartnerType;
//     role: string;
//     relation: string; // designation  from source to target
//     inverseRelation: string;
//     perspective?: 'source' | 'target';
// }

// configuration of possible roles in a relation
// the convention is that the relation represents the natural understanding of: source - role - target
const relationsConfig = [
    {
        source: PartnerType.COMPANY,
        target: PartnerType.COMPANY,
        role: "isHoldingOf",
        relation: "Is holding of",
        inverseRelation: "Is subsidiary of"
    },
    {
        source: PartnerType.PERSON,
        target: PartnerType.COMPANY,
        relation: "is employee of",
        inverseRelation: "employs",
        role: "isEmployeeOf"
    },
    {
        source: PartnerType.COMPANY,
        target: PartnerType.COMPANY,
        relation: "is supplier of",
        inverseRelation: "has supplier",
        role: "isSupplierOf",
    },
];
var RelationRole;
(function (RelationRole) {
    RelationRole["HOLDING_OF"] = "isHoldingOf";
    RelationRole["EMPLOYEE_OF"] = "isEmployeeOf";
    RelationRole["SUPPLIER_OF"] = "isSupplierOf";
})(RelationRole || (RelationRole = {}));
const relationRoles = [];
for (let n in RelationRole) {
    relationRoles.push(PartnerType[n]);
}
class RelationConfigService {
    constructor() {
    }
    // -----------------------------------------------------------------------------------------------------
    // @ Utility Methods
    // -----------------------------------------------------------------------------------------------------
    /**
     *
     * @param type1
     * @param type2
     * @returns all relation configs where type1 -> type2 or type2 -> type1
     */
    static getRelationConfigsUndirected(type1, type2) {
        const _config = relationsConfig.filter((value => (value.source === type1 && value.target === type2) ||
            (value.source === type2 && value.target === type1)));
        return _config;
    }
    /**
     *
     * @param source
     * @param target
     * @returns all relation configs that exist from source type to target type
     */
    static getRelationConfigsDirected(source, target) {
        const _relationConfig = relationsConfig.filter((value => (value.source === source && value.target === target)));
        return _relationConfig;
    }
    /**
     *
     * @param role
     * @returns the unique RelationConfig for a role
     */
    static getRelationConfigForRole(role) {
        const _relationConfig = relationsConfig.filter(value => value.role === role).find(x => x !== undefined);
        return _relationConfig;
    }
    /**
     *
     * @param rel relation
     * @param partnerId the partner that appears either as source or as target in rel
     * @returns returns the relation designation
     */
    static getDisplayedRelation(rel, partnerId) {
        let config = this.getRelationConfigForRole(rel.role);
        return rel.sourcePartner.partnerId === partnerId ? config.relation : config.inverseRelation;
    }
    /**
     *
     * @param type
     * @returns all configurations including type either as source or target
     */
    static getRelationConfigsIncludingType(type) {
        let configs = relationsConfig.filter(value => value.source === type || value.target === type);
        for (let config of configs) {
            if (config.target === type) {
                config.perspective = 'target';
            }
            else {
                config.perspective = 'source';
            }
        }
        return configs;
    }
    /**
     *
     * @param type
     * @returns all configurations including type either source
     */
    static getRelationConfigsIncludingTypeAsSource(type) {
        let res = _.cloneDeep((relationsConfig.filter(value => value.source === type)));
        for (let val of res) {
            val.perspective = 'source';
        }
        return res;
    }
    /**
     *
     * @param type
     * @returns all configurations including type either source
     */
    static getRelationConfigsIncludingTypeAsTarget(type) {
        let res = _.cloneDeep(relationsConfig.filter(value => value.target === type));
        for (let val of res) {
            val.perspective = 'target';
        }
        return res;
    }
}

/**
*	@generator rest2ts
*	javaType: inc.yukawa.chain.crm.partner.service.rest.ContactLogRest <br/>
*/
class ContactLogRest {
    constructor(httpService) {
        this.httpService = httpService;
    }
    queryMyActivities(filter) {
        let headers = new HttpHeaders().set('Content-type', 'application/json');
        return this.httpService.post('/contactlogs/queryMyActivities', filter, { headers });
    }
    queryMyToDos(filter) {
        let headers = new HttpHeaders().set('Content-type', 'application/json');
        return this.httpService.post('/contactlogs/queryMyToDos', filter, { headers });
    }
}
/** @nocollapse */ ContactLogRest.ɵfac = function ContactLogRest_Factory(t) { return new (t || ContactLogRest)(i0.ɵɵinject(i1.HttpClient)); };
/** @nocollapse */ ContactLogRest.ɵprov = i0.ɵɵdefineInjectable({ token: ContactLogRest, factory: ContactLogRest.ɵfac });
/*@__PURE__*/ (function () { i0.ɵsetClassMetadata(ContactLogRest, [{
        type: Injectable
    }], function () { return [{ type: i1.HttpClient }]; }, null); })();
/**
*	@generator rest2ts
*	javaType: inc.yukawa.chain.crm.partner.service.rest.PartnerImportRest <br/>
*/
class PartnerImportRest {
    constructor(httpService) {
        this.httpService = httpService;
    }
    importPartners() {
        return this.httpService.post('/partners/import', null);
    }
}
/** @nocollapse */ PartnerImportRest.ɵfac = function PartnerImportRest_Factory(t) { return new (t || PartnerImportRest)(i0.ɵɵinject(i1.HttpClient)); };
/** @nocollapse */ PartnerImportRest.ɵprov = i0.ɵɵdefineInjectable({ token: PartnerImportRest, factory: PartnerImportRest.ɵfac });
/*@__PURE__*/ (function () { i0.ɵsetClassMetadata(PartnerImportRest, [{
        type: Injectable
    }], function () { return [{ type: i1.HttpClient }]; }, null); })();
/**
*	@generator rest2ts
*	javaType: inc.yukawa.chain.crm.partner.service.rest.PartnerRest <br/>
*/
class PartnerRest {
    constructor(httpService) {
        this.httpService = httpService;
    }
    mergeCollectionAppend(entity) {
        let headers = new HttpHeaders().set('Content-type', 'application/json');
        return this.httpService.post('/partners/collections/append', entity, { headers });
    }
    mergeCollectionRemove(entity) {
        let headers = new HttpHeaders().set('Content-type', 'application/json');
        return this.httpService.post('/partners/collections/remove', entity, { headers });
    }
    /**
    *	partner template (will not be saved)
    */
    newPartner() {
        return this.httpService.post('/partners/new', null);
    }
    putCollection(entity) {
        let headers = new HttpHeaders().set('Content-type', 'application/json');
        return this.httpService.post('/partners/collections/put', entity, { headers });
    }
    putMany(entities) {
        let headers = new HttpHeaders().set('Content-type', 'application/json');
        return this.httpService.post('/partners/putMany', entities, { headers });
    }
    uploadImage(partnerId) {
        return this.httpService.post('/partners/uploadImage/' + partnerId + '', null);
    }
}
/** @nocollapse */ PartnerRest.ɵfac = function PartnerRest_Factory(t) { return new (t || PartnerRest)(i0.ɵɵinject(i1.HttpClient)); };
/** @nocollapse */ PartnerRest.ɵprov = i0.ɵɵdefineInjectable({ token: PartnerRest, factory: PartnerRest.ɵfac });
/*@__PURE__*/ (function () { i0.ɵsetClassMetadata(PartnerRest, [{
        type: Injectable
    }], function () { return [{ type: i1.HttpClient }]; }, null); })();
/**
*	@generator rest2ts
*	javaType: inc.yukawa.chain.crm.partner.service.rest.PartnerTemplateRest <br/>
*/
class PartnerTemplateRest {
    constructor(httpService) {
        this.httpService = httpService;
    }
    delete() {
        return this.httpService.post('/partner-templates/delete', null);
    }
    load() {
        return this.httpService.get('/partner-templates/');
    }
    put(entity) {
        let headers = new HttpHeaders().set('Content-type', 'application/json');
        return this.httpService.post('/partner-templates/put', entity, { headers });
    }
}
/** @nocollapse */ PartnerTemplateRest.ɵfac = function PartnerTemplateRest_Factory(t) { return new (t || PartnerTemplateRest)(i0.ɵɵinject(i1.HttpClient)); };
/** @nocollapse */ PartnerTemplateRest.ɵprov = i0.ɵɵdefineInjectable({ token: PartnerTemplateRest, factory: PartnerTemplateRest.ɵfac });
/*@__PURE__*/ (function () { i0.ɵsetClassMetadata(PartnerTemplateRest, [{
        type: Injectable
    }], function () { return [{ type: i1.HttpClient }]; }, null); })();
/**
*	@generator rest2ts
*	javaType: inc.yukawa.chain.crm.partner.service.rest.RelationRest <br/>
*/
class RelationRest {
    constructor(httpService) {
        this.httpService = httpService;
    }
    putMany(entities) {
        let headers = new HttpHeaders().set('Content-type', 'application/json');
        return this.httpService.post('/relations/putMany', entities, { headers });
    }
    traverseRelations(partnerId, role, traversalDir) {
        const queryParamsList = [];
        queryParamsList.push({ name: 'partnerId', value: partnerId });
        queryParamsList.push({ name: 'role', value: role });
        queryParamsList.push({ name: 'traversalDir', value: traversalDir });
        let params = new HttpParams();
        for (const queryParam of queryParamsList) {
            params = params.append(queryParam.name, queryParam.value);
        }
        return this.httpService.post('/relations/traverse', null, { params });
    }
}
/** @nocollapse */ RelationRest.ɵfac = function RelationRest_Factory(t) { return new (t || RelationRest)(i0.ɵɵinject(i1.HttpClient)); };
/** @nocollapse */ RelationRest.ɵprov = i0.ɵɵdefineInjectable({ token: RelationRest, factory: RelationRest.ɵfac });
/*@__PURE__*/ (function () { i0.ɵsetClassMetadata(RelationRest, [{
        type: Injectable
    }], function () { return [{ type: i1.HttpClient }]; }, null); })();
/**
*	@generator rest2ts
*	javaType: inc.yukawa.chain.crm.partner.service.rest.ReminderRest <br/>
*/
class ReminderRest {
    constructor(httpService) {
        this.httpService = httpService;
    }
}
/** @nocollapse */ ReminderRest.ɵfac = function ReminderRest_Factory(t) { return new (t || ReminderRest)(i0.ɵɵinject(i1.HttpClient)); };
/** @nocollapse */ ReminderRest.ɵprov = i0.ɵɵdefineInjectable({ token: ReminderRest, factory: ReminderRest.ɵfac });
/*@__PURE__*/ (function () { i0.ɵsetClassMetadata(ReminderRest, [{
        type: Injectable
    }], function () { return [{ type: i1.HttpClient }]; }, null); })();

class CrmRealm extends MainRealm {
}
CrmRealm.ROLE_CRM_ADMIN = "ROLE_CRM_ADMIN";
CrmRealm.ROLE_CRM_EDITOR = "ROLE_CRM_EDITOR";
CrmRealm.ROLE_CRM_READER = "ROLE_CRM_READER";
CrmRealm.ROLE_PARTNER_ADMIN = "ROLE_PARTNER_ADMIN";
CrmRealm.ROLE_PARTNER_EDITOR = "ROLE_PARTNER_EDITOR";
CrmRealm.ROLE_PARTNER_READER = "ROLE_PARTNER_READER";
CrmRealm.ROLE_CONTACTLOG_ADMIN = "ROLE_CONTACTLOG_ADMIN";
CrmRealm.ROLE_CONTACTLOG_EDITOR = "ROLE_CONTACTLOG_EDITOR";
CrmRealm.ROLE_CONTACTLOG_READER = "ROLE_CONTACTLOG_READER";
CrmRealm.ROLE_RELATION_ADMIN = "ROLE_RELATION_ADMIN";
CrmRealm.ROLE_RELATION_EDITOR = "ROLE_RELATION_EDITOR";
CrmRealm.ROLE_RELATION_READER = "ROLE_RELATION_READER";
CrmRealm.ROLE_REMINDER_ADMIN = "ROLE_REMINDER_ADMIN";
CrmRealm.ROLE_REMINDER_EDITOR = "ROLE_REMINDER_EDITOR";
CrmRealm.ROLE_REMINDER_READER = "ROLE_REMINDER_READER";
CrmRealm.ADMINS = [BaseRealm.ROLE_ADMIN, CrmRealm.ROLE_CRM_ADMIN];
CrmRealm.EDITORS = [...CrmRealm.ADMINS, CrmRealm.ROLE_CRM_EDITOR];
CrmRealm.READERS = [...CrmRealm.EDITORS, CrmRealm.ROLE_CRM_READER];
CrmRealm.PARTNER_EDITORS = [...CrmRealm.EDITORS, CrmRealm.ROLE_PARTNER_EDITOR];
CrmRealm.PARTNER_READERS = [...CrmRealm.READERS, ...CrmRealm.PARTNER_EDITORS, CrmRealm.ROLE_PARTNER_READER];

// modules
// services
class CRMCoreModule {
    static forRoot() {
        return {
            ngModule: CRMCoreModule,
            providers: [
                AccountService, ContactLogService, RelationService, RelationConfigService
            ]
        };
    }
}
/** @nocollapse */ CRMCoreModule.ɵmod = i0.ɵɵdefineNgModule({ type: CRMCoreModule });
/** @nocollapse */ CRMCoreModule.ɵinj = i0.ɵɵdefineInjector({ factory: function CRMCoreModule_Factory(t) { return new (t || CRMCoreModule)(); }, providers: [], imports: [[
            CommonModule,
            HttpClientModule,
            TranslateModule.forChild()
        ]] });
(function () { (typeof ngJitMode === "undefined" || ngJitMode) && i0.ɵɵsetNgModuleScope(CRMCoreModule, { imports: [CommonModule,
        HttpClientModule, i1$1.TranslateModule] }); })();
/*@__PURE__*/ (function () { i0.ɵsetClassMetadata(CRMCoreModule, [{
        type: NgModule,
        args: [{
                imports: [
                    CommonModule,
                    HttpClientModule,
                    TranslateModule.forChild()
                ],
                declarations: [],
                exports: [],
                providers: [],
                entryComponents: [],
                schemas: [CUSTOM_ELEMENTS_SCHEMA]
            }]
    }], null, null); })();

/*
 * Public API
 */

/**
 * Generated bundle index. Do not edit.
 */

export { AccountService, AccountUtilities, AddressUtils, CRMCoreModule, ContactLogRest, ContactLogService, ContactLogStatus, CrmRealm, PartnerImportRest, PartnerRest, PartnerTemplateRest, PartnerType$1 as PartnerType, RelationConfigService, RelationRest, RelationRole, RelationService, ReminderRest, contactLogStatus, partnerTypes$1 as partnerTypes, relationRoles, relationsConfig, sortByCompanyName, sortByLastName, withId, withType };
//# sourceMappingURL=yukawa-chain-crm-angular-core.js.map
